local wezterm = require 'wezterm'
local config = {}
local machine_specific = require("machine_specific")

config.font = wezterm.font 'IosevkaTermSlab Nerd Font Mono'
config.font_size = 11.0

config.cursor_blink_rate = 800

config.window_padding = {
	left = "3px",
	right = 0,
	top = "1px",
	bottom = 0,
}

config.window_decorations = "NONE"
config.window_frame = {
	inactive_titlebar_bg = '#2d2d2d',
	active_titlebar_bg = '#232323',
}

config.use_fancy_tab_bar = false
config.enable_tab_bar = machine_specific.enable_tab_bar

config.colors = {
	background = '#101010',
	foreground = '#BBBBBB',

	cursor_bg = '#22785E',
	cursor_fg = '#000000',

	selection_fg = '#D3D7CF',
	selection_bg = '#262626',

	tab_bar = {
		active_tab = {
			bg_color = "#101010",
			fg_color = "#BBBBBB",
		},
		inactive_tab = {
			bg_color = "#232323",
			fg_color = "#BBBBBB",
		},
	},

	--	#black,    #red,      #green,    #yellow,    #blue,     #magenta,  #cyan,     #white
	ansi = {
		"#010101", "#d62222", "#3ba04d", "#f6e000", "#1958ff", "#b300b3", "#10bfaf", "#c6c6c6"
	},
	brights = {
		"#606060", "#ff4444", "#3bd04d", "#dfff1f", "#01a9ff", "#f600f6", "#10efdf", "#e9e9e9"
	},
}

config.inactive_pane_hsb = {
	saturation = 1.0,
	brightness = 0.4,
}

config.keys = {
	{
		key = 'h', mods = 'CTRL',
		action = wezterm.action.SplitHorizontal
		{
			domain = 'CurrentPaneDomain'
		},
	},
	{
		key = 'v', mods = 'CTRL',
		action = wezterm.action.SplitVertical
		{
			domain = 'CurrentPaneDomain'
		},
	},
	{
		key = 'w', mods = 'CTRL',
		action = wezterm.action.CloseCurrentPane
		{
			confirm = true
		},
	},
}

return config
